==> rsuite-5.62.0.tgz: package/esm/Placeholder/PlaceholderParagraph.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject;
import React, { useMemo } from 'react';
import PropTypes from 'prop-types';
import { useClassNames } from "../internals/hooks";
import { oneOf } from "../internals/propTypes";
/**
 * The `Placeholder.Paragraph` component is used to display the loading state of the block.
 * @see https://rsuitejs.com/components/placeholder
 */
var PlaceholderParagraph = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    className = props.className,
    _props$rows = props.rows,
    rows = _props$rows === void 0 ? 2 : _props$rows,
    _props$rowHeight = props.rowHeight,
    rowHeight = _props$rowHeight === void 0 ? 10 : _props$rowHeight,
    _props$rowMargin = props.rowMargin,
    rowMargin = _props$rowMargin === void 0 ? 20 : _props$rowMargin,
    _props$rowSpacing = props.rowSpacing,
    rowSpacing = _props$rowSpacing === void 0 ? rowMargin : _props$rowSpacing,
    graph = props.graph,
    active = props.active,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'placeholder' : _props$classPrefix,
    rest = _objectWithoutPropertiesLoose(props, ["as", "className", "rows", "rowHeight", "rowMargin", "rowSpacing", "graph", "active", "classPrefix"]);
  var _useClassNames = useClassNames(classPrefix),
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix,
    withClassPrefix = _useClassNames.withClassPrefix;
  var graphShape = graph === true ? 'square' : graph;
  var rowElements = useMemo(function () {
    var rowArr = [];
    for (var i = 0; i < rows; i++) {
      var styles = {
        height: rowHeight,
        marginTop: i > 0 ? rowSpacing : Number(rowSpacing) / 2
      };
      rowArr.push( /*#__PURE__*/React.createElement("div", {
        key: i,
        style: styles,
        className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["row"])))
      }));
    }
    return rowArr;
  }, [prefix, rowHeight, rowSpacing, rows]);
  var classes = merge(className, withClassPrefix('paragraph', {
    active: active
  }));
  var graphClasses = prefix('paragraph-graph', "paragraph-graph-" + graphShape);
  return /*#__PURE__*/React.createElement(Component, _extends({}, rest, {
    ref: ref,
    className: classes
  }), graphShape && /*#__PURE__*/React.createElement("div", {
    className: graphClasses
  }, /*#__PURE__*/React.createElement("span", {
    className: prefix('paragraph-graph-inner')
  })), /*#__PURE__*/React.createElement("div", {
    className: prefix('paragraph-group')
  }, rowElements));
});
PlaceholderParagraph.displayName = 'PlaceholderParagraph';
PlaceholderParagraph.propTypes = {
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  rows: PropTypes.number,
  rowHeight: PropTypes.number,
  rowSpacing: PropTypes.number,
  graph: PropTypes.oneOfType([PropTypes.bool, oneOf(['circle', 'square', 'image'])]),
  active: PropTypes.bool
};
export default PlaceholderParagraph;

==> rsuite-5.63.0.tgz: package/esm/Placeholder/PlaceholderParagraph.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject;
var _excluded = ["as", "className", "rows", "rowHeight", "rowMargin", "rowSpacing", "graph", "active", "classPrefix"];
import React, { useMemo } from 'react';
import PropTypes from 'prop-types';
import { useClassNames } from "../internals/hooks/index.js";
import { oneOf } from "../internals/propTypes/index.js";
/**
 * The `Placeholder.Paragraph` component is used to display the loading state of the block.
 * @see https://rsuitejs.com/components/placeholder
 */
var PlaceholderParagraph = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    className = props.className,
    _props$rows = props.rows,
    rows = _props$rows === void 0 ? 2 : _props$rows,
    _props$rowHeight = props.rowHeight,
    rowHeight = _props$rowHeight === void 0 ? 10 : _props$rowHeight,
    _props$rowMargin = props.rowMargin,
    rowMargin = _props$rowMargin === void 0 ? 20 : _props$rowMargin,
    _props$rowSpacing = props.rowSpacing,
    rowSpacing = _props$rowSpacing === void 0 ? rowMargin : _props$rowSpacing,
    graph = props.graph,
    active = props.active,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'placeholder' : _props$classPrefix,
    rest = _objectWithoutPropertiesLoose(props, _excluded);
  var _useClassNames = useClassNames(classPrefix),
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix,
    withClassPrefix = _useClassNames.withClassPrefix;
  var graphShape = graph === true ? 'square' : graph;
  var rowElements = useMemo(function () {
    var rowArr = [];
    for (var i = 0; i < rows; i++) {
      var styles = {
        height: rowHeight,
        marginTop: i > 0 ? rowSpacing : Number(rowSpacing) / 2
      };
      rowArr.push( /*#__PURE__*/React.createElement("div", {
        key: i,
        style: styles,
        className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["row"])))
      }));
    }
    return rowArr;
  }, [prefix, rowHeight, rowSpacing, rows]);
  var classes = merge(className, withClassPrefix('paragraph', {
    active: active
  }));
  var graphClasses = prefix('paragraph-graph', "paragraph-graph-" + graphShape);
  return /*#__PURE__*/React.createElement(Component, _extends({}, rest, {
    ref: ref,
    className: classes
  }), graphShape && /*#__PURE__*/React.createElement("div", {
    className: graphClasses
  }, /*#__PURE__*/React.createElement("span", {
    className: prefix('paragraph-graph-inner')
  })), /*#__PURE__*/React.createElement("div", {
    className: prefix('paragraph-group')
  }, rowElements));
});
PlaceholderParagraph.displayName = 'PlaceholderParagraph';
PlaceholderParagraph.propTypes = {
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  rows: PropTypes.number,
  rowHeight: PropTypes.number,
  rowSpacing: PropTypes.number,
  graph: PropTypes.oneOfType([PropTypes.bool, oneOf(['circle', 'square', 'image'])]),
  active: PropTypes.bool
};
export default PlaceholderParagraph;
